{% import "bootstrap/wtf.html" as wtf %}
{% extends "auth/base.html" %}


{% block page_content %}
<div class="container">
    <div class="d-flex justify-content-center">
        <h1>Confirm login</h1>
    </div>
    <div class="d-flex justify-content-center m-5">
        You are attempting to perform a sensitive action. Please confirm your login credentials.
    </div>
    
    <div class="d-flex justify-content-center">
        {{ wtf.quick_form(form) }}
        <br>
    </div>
</div>
{% endblock %}