@import "style.css";

body{
    background-color: white;
}

.bg-jobs {
    background-color: #20a8d8 !important;
    background: url("../images/briefcase.svg");
    background-repeat: no-repeat;
    background-size: 200px auto;
    background-position: 75% 50%;

}

.card.bg-jobs {
    border-color: #187da0;
  }

.bg-flowcharts {
    background-color: #ffc107  !important;
    background: url("../images/project-diagram.svg");
    background-repeat: no-repeat;
    background-size: 250px auto;
    background-position: 75% 50%;

}

.card.bg-flowcharts {
    border-color: #c69500;
}

.bg-projects {
    background-color: #f86c6b  !important;
    background: url("../images/object-group.svg");
    background-repeat: no-repeat;
    background-size: 250px auto;
    background-position: 75% 50%;

}

.card.bg-projects {
    border-color: #f5302e;
}


.fade-text {
    display: -webkit-box;
    -webkit-line-clamp: 5;
    -webkit-box-orient: vertical;  
}

.hidden {
	display: none;
	height: 0;
    opacity: 0;
	overflow: hidden;
	transition: height 350ms ease-in-out, opacity 750ms ease-in-out;
}
  